Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: src/x64/macro-assembler-x64.h

Issue 2622833002: WIP [esnext] implement async iteration proposal (Closed)
Patch Set: simplify AsyncIteratorValueUnwrap Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/v8.gyp ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/x64/macro-assembler-x64.h
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h
index 795ba912fad7c0b38ec8a3e436f45b06cb7928b9..c04c5fa915f0dcacf0ff1ad3f7bff1b4bf8f9b0f 100644
--- a/src/x64/macro-assembler-x64.h
+++ b/src/x64/macro-assembler-x64.h
@@ -1237,10 +1237,14 @@ class MacroAssembler: public Assembler {
// enabled via --debug-code.
void AssertBoundFunction(Register object);
// Abort execution if argument is not a JSGeneratorObject,
// enabled via --debug-code.
void AssertGeneratorObject(Register object);
+ // Abort execution if argument is not a JSAsyncGeneratorObject, enabled via
+ // --debug-code.
+ void AssertAsyncGeneratorObject(Register object);
+
// Abort execution if argument is not a JSReceiver, enabled via --debug-code.
void AssertReceiver(Register object);
« no previous file with comments | « src/v8.gyp ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »
@@ -1237,10 +1237,14 @@ class MacroAssembler: public Assembler {
// enabled via --debug-code.
void AssertBoundFunction(Register object);
- // Abort execution if argument is not a JSGeneratorObject,
- // enabled via --debug-code.
+ // Abort execution if argument is not a JSGeneratorObject or a
+ // JSAsyncGeneratorObject, enabled via --debug-code.
void AssertGeneratorObject(Register object);

Powered by Google App Engine
This is Rietveld 408576698